#!/usr/bin/env ruby
require("gsl")

N = 10000
r = GSL::Rng.new
v = r.gaussian(1, N)
h = v.histogram(100, -4, 4)
h.graph

